annotation_get: Get GO annotations

Description Usage Arguments Value

Description

Get Gene Ontology (GO) annotations is a tidy data.frame. This function is customized to extract the lower level GO IDs before finding the gene products associated with each ID. Finally, the term corresponding to each ID is added

Usage

1
2
annotation_get(go_id, go_names, go_db, go_term, org_db, columns,
  remove_predicted = TRUE, ...)

Arguments

go_id

A character vector of GO IDs

go_names

A character vector of GO category names

go_db

A GO.db object

go_term

A GO.db object for GO terms

org_db

An organism object

columns

A charachter vector

remove_predicted

A logical (default, TRUE) for removing predicted genes

...

Other arguments passed to select

Value

A data.frame of at least 6 columns

#' @examples ## Not run: # load required libraries library(org.Mm.eg.db) library(GO.db) # prepare query go_ids <- c('GO:0006914', 'GO:0004679') go_names <- c('autophagy', 'AMPK') go_db <- GOBPCHILDREN go_term <- GOTERM org_db <- org.Mm.eg.db columns <- 'SYMBOL' # call function ann <- annotation_get(go_ids, go_names, go_db, go_term, org_db, columns) ## End(Not run)


MahShaaban/aacna documentation built on May 17, 2019, 6:21 p.m.