expression_subset: Subset an ExpressionSet

Description Usage Arguments Value Examples

Description

Subset an ExpressionSet object by row and/or column, and perform collapse of repeated probes corresponding to the same gene ID

Usage

1
expression_subset(eset, byrow, bycol, collapse_rows = FALSE, ...)

Arguments

eset

An ExpressionSet object

byrow

A logical vector masking rows of eset

bycol

A logical vector masking columns of eset

collapse_rows

A logical (default FALSE)

...

Other arguments passed to collapse_rows

Value

A tidy expression matrix. The dimensions of the matrix are either equal to the byrow and bycol argumnets when collapse_rows is FALSE, or equal the rowGroup and the bycol arguments otherwise

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
library(Biobase)
data("sample.ExpressionSet")

pd <- pData(sample.ExpressionSet)

set.seed(123)
byrow <- sample(c(TRUE, FALSE), nrow(sample.ExpressionSet), replace = TRUE)
bycol <- pd$sex == 'Female'

expression_subset(sample.ExpressionSet, byrow, bycol)

MahShaaban/aacna documentation built on May 17, 2019, 6:21 p.m.