Description Usage Arguments Value
Get Gene Ontology (GO) annotations is a tidy data.frame. This function is customized to extract the lower level GO IDs before finding the gene products associated with each ID. Finally, the term corresponding to each ID is added
1 2 | annotation_get(go_id, go_names, go_db, go_term, org_db, columns,
remove_predicted = TRUE, ...)
|
go_id |
A character vector of GO IDs |
go_names |
A character vector of GO category names |
go_db |
A GO.db object |
go_term |
A GO.db object for GO terms |
org_db |
An organism object |
columns |
A charachter vector |
remove_predicted |
A logical (default, TRUE) for removing predicted genes |
... |
Other arguments passed to select |
A data.frame of at least 6 columns
category The category/ies as in go_names
go The GO ID/s as in go_id or their lower level components
evidence The type of evidence for each gene product
ontology The type of ontology (e.g. BP, MF and/or CC)
(column/s) The query columns as in columns
term The term corresponding to each GO ID
#' @examples ## Not run: # load required libraries library(org.Mm.eg.db) library(GO.db) # prepare query go_ids <- c('GO:0006914', 'GO:0004679') go_names <- c('autophagy', 'AMPK') go_db <- GOBPCHILDREN go_term <- GOTERM org_db <- org.Mm.eg.db columns <- 'SYMBOL' # call function ann <- annotation_get(go_ids, go_names, go_db, go_term, org_db, columns) ## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.